# File: ZEO-1.0b4.spec
#
# Digicool Z-Object Programming Environment (ZOPE)
#
#   "Zope Enterprise Objects"
#
# An independent 'BuildRoot:' directive is used so that that this package
# can be built in the /var/tmp directory, for the case where the existing
# software on the build host would be disrupted by installing-after-build-
# to-package onto that system.
#
# Sample Package Names:
#   ZEO-1.0b4-1.noarch.rpm
#
####

####
# Section: Preamble (Items Displayed When Users Request Info About Package)
#
# The order of the entries below is unimportant.
#
####

%define PYTHONAPP /usr/bin/python2.1
%define PYTHONDIR python2.1

Name:               ZEO
Version:            1.0b4
Release:            1
Copyright:          Zope Public License (ZPL)
Vendor:             Zope Corporation
URL:                http://www.zope.org/
Packager:           Jeff Rush <jrush@taupro.com>
BuildRoot:          /var/tmp/ZEO-%{version}-rootdir
Prereq:             python2 python2-devel /sbin/chkconfig

Source0: http://www.zope.org/Download/Releases/ZEO-%{version}.tgz
Source1: %{name}-%{version}-zeo
Source2: %{name}-%{version}-myclient.py
Source3: %{name}-%{version}-mystorage.py
Source4: %{name}-%{version}-start_zeo

#----------------------------------------------------------------------
Summary:            A distributed object-oriented database adapter for Zope.
Group:              Applications/Databases
Requires:           python2 >= 2.1
BuildArchitectures: noarch

%description

Zope Enterprise Objects

Zope Enterprise Objects (ZEO) extends the Zope Object Database
(ZODB) to multiple processes, machines, and locations.  It provides
scalability, high availability, and distribution for ZODB.  For more
information, see the ZEO Web page at http://www.zope.org/Products/ZEO/.

If you are using Zope, see docs/ZopeREADME.txt; otherwise, see
docs/NonZopeREADME.txt. 

########## 
#
# The following environment variables are automatically defined for use
# in any of the following shell scripts:
#
#   RPM_SOURCE_DIR      { where sources originally reside }
#   RPM_BUILD_DIR       { where sources get unpacked into }
#   RPM_DOC_DIR
#   RPM_OPT_FLAGS
#   RPM_ARCH
#   RPM_OS
#   RPM_ROOT_DIR
#   RPM_BUILD_ROOT      { where final images get placed before packaging }
#   RPM_PACKAGE_NAME
#   RPM_PACKAGE_VERSION
#   RPM_PACKAGE_RELEASE
#
##########

####
# Section: Prep Script (Prepare to Build; Usually Just Unpacking the Sources)
####
%prep
# Create Build Subdirectory and Unpack the Main Tar Ball
%setup -q -n %{name}-%{version}

# Reset RPM's Concept of "-n" Back to the Top-Level Package Dir Name
%setup -q -T -D -n %{name}-%{version}

####
# Section: Build Script (Actually Perform the Build; Usually Just 'make')
####
%build

####
# Section: Install-After-Build Script (Often Just 'make install')
####
%install
  rm -rf $RPM_BUILD_ROOT

  # Make the Necessary Directories
  install -m0755 --directory      $RPM_BUILD_ROOT/usr/lib/%{PYTHONDIR}/site-packages
  install -m0755 --directory      $RPM_BUILD_ROOT/etc/rc.d/init.d
  install -m0775 --directory      $RPM_BUILD_ROOT/var/zeo
  install -m0775 --directory      $RPM_BUILD_ROOT/var/zeo/Extensions
  install -m0711 --directory      $RPM_BUILD_ROOT/var/zeo/var
  install -m0775 --directory      $RPM_BUILD_ROOT/var/zeo/Products
  install -m0775 --directory      $RPM_BUILD_ROOT/var/log

  cp -Rdp         ZEO/            $RPM_BUILD_ROOT/usr/lib/%{PYTHONDIR}/site-packages/

  install -m 0755 %{SOURCE1}      $RPM_BUILD_ROOT/etc/rc.d/init.d/zeo
  install -m 0755 %{SOURCE2}      $RPM_BUILD_ROOT/var/zeo/myclient.py
  install -m 0644 %{SOURCE3}      $RPM_BUILD_ROOT/var/zeo/mystorage.py
  install -m 0755 %{SOURCE4}      $RPM_BUILD_ROOT/var/zeo/start_zeo

  # Precompile Python Source for Faster Imports During Usage
  # (Since user of package may not have write-access to install directory)
  %{PYTHONAPP} -O /usr/lib/%{PYTHONDIR}/compileall.py    -d /usr/lib/%{PYTHONDIR}/  $RPM_BUILD_ROOT/usr/lib/%{PYTHONDIR}
  %{PYTHONAPP}    /usr/lib/%{PYTHONDIR}/compileall.py    -d /usr/lib/%{PYTHONDIR}/  $RPM_BUILD_ROOT/usr/lib/%{PYTHONDIR}

  # Create a Safe Preowned Zope Logfile, for ZServer
  # (Otherwise a symlink-redirect attack may be possible!)
  touch $RPM_BUILD_ROOT/var/log/zeo

####
# Section: Delivery Install/Uninstall Scripts (Pre/Post Install/Erase Scripts)
####

%pre
  /usr/sbin/useradd -M -r -s /bin/bash -d /var/zeo -c "Zope Enterprise Objects Server" zeo >/dev/null 2>&1 || :

%post
  /sbin/chkconfig --add zeo

%preun
  if [ "$1" = 0 ] ; then
    /etc/rc.d/init.d/zeo stop > /dev/null 2>&1
    /sbin/chkconfig --del zeo
  fi

%postun
  if [ $1 = 0 ] ; then
	userdel zeo >/dev/null 2>&1 || :
  fi
  if [ "$1" -ge "1" ]; then
	/etc/rc.d/init.d/lpd condrestart > /dev/null 2>&1
  fi

####
# Section: Verify Script (Check for Proper Installation of Package)
####

####
# Section: Clean Script (Tidy Up Build Area After a Build Completes)
####
%clean
  rm -rf $RPM_BUILD_ROOT

####
# Section: Files (List of Files w/Attributes Making Up Package)
####

%files
  %defattr(-, root, root, 0755)

  %doc CHANGES.txt  README
  %doc docs/*
  %doc misc/
  /usr/lib/%{PYTHONDIR}/site-packages/ZEO/

  %config				/etc/rc.d/init.d/zeo

  # IMPORTANT: ZEO runs as user 'zeo' and
  #            must have r/w access to the var/ directory
  #            so that it can create temp and index files.
  %defattr(-, zeo, root, 0755)

  %dir					/var/zeo/
  %dir					/var/zeo/Products
  %dir					/var/zeo/var/
  %verify(not size md5 mtime)		/var/log/zeo
  %config				/var/zeo/start_zeo
  %config				/var/zeo/mystorage.py
  %config				/var/zeo/myclient.py

%changelog
* Tue Sep 18 2001 Jeff Rush <jrush@taupro.com>
  Packaged ZEO 1.0b4.

